@@ -12,6 +12,7 @@ from jinja2 import Template
 from .tool import log
 from configparser import ConfigParser, ExtendedInterpolation
 from typing import Union, Any, Callable
+from .abstract_object import AbstractResponse, AbstractShell
 
 
 def is_posix():
@@ -48,7 +49,7 @@ class ExecuteCommandError(BaseSCError):
     pass
 
 
-class Response:
+class ServerResponse(AbstractResponse):
     class color:
         """https://habr.com/ru/company/macloud/blog/558316/
         """
@@ -111,11 +112,11 @@ class Response:
         print(self)
 
 
-class RemoteShell:
+class RemoteShell(AbstractShell):
 
     def __init__(self,
                  server: str, user: str, port=22, password=None,
-                 response=Response):
+                 response=ServerResponse):
         self.response = response
         self.server = server
         self.port = port
@@ -187,13 +188,14 @@ class RemoteShell:
 class Server:
 
     def __init__(self, server:str, user:str, port:int=22,
-                 password=None, pkey=None, response=Response
+                 password=None, pkey=None, response=ServerResponse, debug=False,
                  ):
-
+        self.debug = debug
         self.response = response
         self._shell = RemoteShell(server, user, port=port, password=password,
                                   response=response)
-        logger.info(f"Ok connected to server {server}:{port}")
+        if self.debug:
+            logger.info(f"Ok connected to server {server}:{port}")
 
     def monitor_server(self):
         """https://github.com/afaqurk/linux-dash"""
@@ -203,15 +205,15 @@ class Server:
         response = self.shell("free -h")
         return response
 
-    def shell(self, command: str, debug=True):
+    def shell(self, command: str, output=True):
         response = self._shell.exec_command(command)
-        if debug:
+        if output:
             response.pprint()
         return response
 
-    def struct_shell(self, command: str, debug=True):
+    def struct_shell(self, command: str, output=True):
         response = self._shell.exec_command(command)
-        if debug:
+        if output:
             response.pprint()
         if not response:
             raise ExecuteCommandError(
@@ -251,7 +253,8 @@ class Server:
 
     def close_connect(self):
         self._shell.client.close()
-        logger.info(f"Connect closed the server {self._shell.server}:{self._shell.port}")
+        if self.debug:
+            logger.info(f"Connect closed the server {self._shell.server}:{self._shell.port}")
 
 
 class Config:
